@@ -15,6 +15,7 @@ UTILS = ['program_utils.py', 'file_utils.py', 'aws_s3_utils.py', 'quick_utils.py
 def run_container_local( args ):
     """ Runs a container on the local system (docker run)
     name: name of container
+    registry (optional): external public registry, if not using Bioshed registry
     tag: (optional) tag of container image
     args: program arguments
     need_sudo: (optional)
@@ -33,18 +34,19 @@ def run_container_local( args ):
     AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
                  if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
                  else quick_utils.loadJSON(os.path.join(SCRIPT_DIR,'aws_config_constants.json'))
-    CONTAINER_REGISTRY_URL = AWS_CONFIG['ecr_registry'] if 'ecr_registry' in AWS_CONFIG else DEFAULT_REGISTRY
+    CONTAINER_REGISTRY_URL = args['registry'] if 'registry' in args and args['registry'] != '' else \
+                             (AWS_CONFIG['ecr_registry'] if 'ecr_registry' in AWS_CONFIG else DEFAULT_REGISTRY)
 
     # sudo docker run test:latest
     cname = args['name']
-    ctag = args['tag'] if 'tag' in args else 'latest'
+    ctag = args['tag'] if 'tag' in args and args['tag'] != '' else 'latest'
     pargs = quick_utils.format_type(args['args'], 'string_space') if 'args' in args else ''
     need_sudo = args['need_sudo'] if 'need_sudo' in args else 'y'
     dockerargs = str(args['dockerargs']).strip()+' ' if 'dockerargs' in args else ''
     container_registry = str(CONTAINER_REGISTRY_URL).rstrip('/')
 
     # add local output volume if specified (local output needs to be full path)
-    if 'out::/' in pargs:
+    if 'out::/' in pargs and ':/output/' not in dockerargs:
         local_outdir = pargs[int(pargs.index('out::/')+5):].split(' ')[0]
         dockerargs += '-v {}:/output/ '.format(local_outdir)
 
@@ -267,9 +269,9 @@ def specify_output_dir( args ):
     program_args: list of arguments
     default_dir: default directory if output dir is not provided
     """
-    default_dir = args['default_dir'] if 'default_dir' in args else ''
+    default_dir = str(args['default_dir']) if 'default_dir' in args else ''
     pargs = quick_utils.format_type(args['program_args'], 'space-str')
-    if 'out::' not in pargs and default_dir != '':
+    if 'out::' not in pargs and 's3://' not in pargs and 'gcp://' not in pargs and default_dir != '':
         pargs = pargs.strip()+' out::/'+default_dir.lstrip('/')
         return quick_utils.format_type(pargs, 'list')
     else:
